import React, { KeyboardEvent } from 'react';
import Calendar from './Calendar';
import Combo, { ComboProps } from './Combo';
import { IconRef } from './Icon';
import './css/Input.less';
import { ComponentProps, StrObject } from './components/common';
import { Tooltip } from 'bootstrap';
interface CalendarProps {
    format?: string;
    time?: boolean;
    limit?: {
        lt?: string;
        gt?: string;
    };
}
export interface ValidateProps {
    text?: string;
    rule?: RegExp | ((val: string) => boolean);
    tip?: boolean;
}
interface Props extends ComponentProps {
    label?: any;
    type?: string;
    data?: any;
    summary?: string;
    readOnly?: boolean;
    placeholder?: string;
    calendar?: CalendarProps;
    onChange?: (val: any, row: any, obj?: any) => void;
    onEnter?: (val: any) => void;
    onDblClick?: () => void;
    plaintext?: boolean;
    calendarFormat?: string;
    calendarTime?: boolean;
    validate?: ValidateProps;
    disabled?: boolean;
    combo?: ComboProps;
    comboData?: any;
    align?: string;
    textClass?: string;
    textStyle?: StrObject;
    labelClass?: string;
    disableClear?: boolean;
    multi?: {
        height?: string;
    };
    max?: any;
    min?: any;
    underline?: boolean;
}
interface State {
    value: any;
    validate: boolean;
    disabled: boolean;
    comboData: any;
    icon: string;
}
export declare class Input extends React.Component<Props, State> {
    static defaultProps: {
        size: string;
        label: string;
        data: null;
        summary: string;
        readOnly: boolean;
        disabled: boolean;
        disableClear: boolean;
    };
    domId: string;
    isFocus: boolean;
    input: HTMLInputElement;
    calendar: Calendar;
    combo: Combo;
    clearIcon: IconRef;
    tip: Tooltip;
    mainDom: HTMLElement;
    constructor(props: any);
    componentDidMount(): void;
    componentWillUnmount(): void;
    UNSAFE_componentWillReceiveProps(nextProps: Props): void;
    shouldComponentUpdate(nextProps: Props, nextState: State): boolean;
    getValue(): any;
    setValue(val: any): void;
    getMainClasses(): string;
    getMainStyles(): any;
    getInputClasses(append: string): string;
    getInputStyle(): any;
    check(flag?: boolean): boolean;
    validate(val: string): boolean;
    /*********************
     * Event
     *********************/
    changeHandler: (e: any) => void;
    blurHandler: (e: FocusEvent) => void;
    /**
     * Combo select event
     * @param text stringminimist
     * @param row object
     */
    selectHandler: (text: string, row: any) => void;
    setSelectRows(key: any, val: any): void;
    keyUpHandler: (e: KeyboardEvent) => void;
    focusClearHandler: () => void;
    showMulti: () => void;
    hideMulti: () => void;
    blurClearHandler: () => void;
    /**
     * input dblclick event
     * @param e
     */
    dblHandler: () => void;
    mainDblHandler: () => void;
    /*********************
     * render method
     *********************/
    renderLabel(): JSX.Element | null;
    renderSummary(): JSX.Element | null;
    renderCalendar(): JSX.Element | null;
    renderCombo(): JSX.Element | null;
    renderClear(): JSX.Element | null;
    renderValidateTip(): {
        'data-toggle': string;
        'data-placement': string;
        title: string | undefined;
    } | {
        'data-toggle'?: undefined;
        'data-placement'?: undefined;
        title?: undefined;
    };
    renderDisableMask(): JSX.Element | null;
    render(): JSX.Element;
    renderMulti(): JSX.Element;
}
export default Input;
//# sourceMappingURL=Input.d.ts.map