/**
 * 拖动控制类
 * @author clake
 * @version 0.1
 */
interface MoveEventStart {
    (dragDom: HTMLElement, eventDom: HTMLElement, event: MouseEvent): boolean;
}
interface MoveEventMove {
    (move: {
        x: number;
        y: number;
    }, dragDom: HTMLElement, eventDom: HTMLElement, event: MouseEvent): void;
}
interface MoveEvent {
    start?: MoveEventStart;
    move?: MoveEventMove;
    end?: MoveEventStart;
}
export declare class Drag {
    dragX: number;
    dragY: number;
    domX: number;
    domY: number;
    x: number;
    y: number;
    dragDom: HTMLElement;
    eventDom: HTMLElement;
    _evtStart: MoveEventStart;
    _evtMove?: MoveEventMove;
    _evtEnd: MoveEventStart;
    /**
     * 初始化方法
     * @param dragDom  DOMElement|string   拖动对像,可以传入DOM对像或selector字符串
     * @param eventDom DOMElement|string   拖动事件对像,可以传入DOM对像或selector字符串
     * @param events   object              事件对像,可选多个事件
     */
    constructor(dragDom: HTMLElement | string, eventDom: HTMLElement | string, events: MoveEvent);
    setDragDom(dragDom: HTMLElement | string): void;
    setEventDom(eventDom: HTMLElement | string): void;
    initEvents(events: MoveEvent): void;
    bindEvents(): void;
    unbind(): void;
    beginDrag: (e: MouseEvent) => false | undefined;
    startMove: (e: MouseEvent) => false | undefined;
    moveDrag: (e: MouseEvent) => void;
    overDrag: (e: MouseEvent) => void;
}
export default Drag;
//# sourceMappingURL=Drag.d.ts.map